==> jangaroo-sdk-0.9.3.zip: joo/classes/flash/text/TextExtent.js <==
joo.classLoader.prepare("package flash.text",/* {*/


/**
 * The TextExtent class contains information about the extents of some text in a text field. Objects of this class are returned by the <code>TextFormat.getTextExtent</code> method.
 */
"public class TextExtent",1,function($$private){;return[ 
  /**
   *
   */
  "public var",{ ascent/*:Number*/:NaN},
  /**
   *
   */
  "public var",{ descent/*:Number*/:NaN},
  /**
   *
   */
  "public var",{ height/*:Number*/:NaN},
  /**
   *
   */
  "public var",{ textFieldHeight/*:Number*/:NaN},
  /**
   *
   */
  "public var",{ textFieldWidth/*:Number*/:NaN},
  /**
   *
   */
  "public var",{ width/*:Number*/:NaN},

  /**
   *
   * @param width <code>width:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   * @param height <code>height:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   * @param textFieldWidth <code>textFieldWidth:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   * @param textFieldHeight <code>textFieldHeight:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   * @param ascent <code>ascent:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   * @param descent <code>descent:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   *
   */
  "public function TextExtent",function TextExtent$(width/*:Number*/, height/*:Number*/, textFieldWidth/*:Number*/, textFieldHeight/*:Number*/, ascent/*:Number*/, descent/*:Number*/) {
    throw new Error('not implemented'); // TODO: implement!
  },
];},[],["Error"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/flash/text/TextExtent.js <==
joo.classLoader.prepare("package flash.text",/* {*/


/**
 * The TextExtent class contains information about the extents of some text in a text field. Objects of this class are returned by the <code>TextFormat.getTextExtent</code> method.
 */
"public class TextExtent",1,function($$private){return[ 
  /**
   *
   */
  "public var",{ ascent/*:Number*/:NaN},
  /**
   *
   */
  "public var",{ descent/*:Number*/:NaN},
  /**
   *
   */
  "public var",{ height/*:Number*/:NaN},
  /**
   *
   */
  "public var",{ textFieldHeight/*:Number*/:NaN},
  /**
   *
   */
  "public var",{ textFieldWidth/*:Number*/:NaN},
  /**
   *
   */
  "public var",{ width/*:Number*/:NaN},

  /**
   *
   * @param width <code>width:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   * @param height <code>height:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   * @param textFieldWidth <code>textFieldWidth:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   * @param textFieldHeight <code>textFieldHeight:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   * @param ascent <code>ascent:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   * @param descent <code>descent:<a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/Number.html">Number</a></code>
   *
   */
  "public function TextExtent",function TextExtent(width/*:Number*/, height/*:Number*/, textFieldWidth/*:Number*/, textFieldHeight/*:Number*/, ascent/*:Number*/, descent/*:Number*/) {
    throw new Error('not implemented'); // TODO: implement!
  },
undefined];},[],["Error"], "0.8.0", "0.9.12"
);
